@@ -1,12 +1,17 @@
-import paramiko
-from paramiko.client import SSHClient, AutoAddPolicy
 from pathlib import Path
 from typing import List, Union, Optional
 import logging
 import io
 
+try:
+    import paramiko
+    from paramiko.client import SSHClient, AutoAddPolicy
+except:
+    print("SSH Tasks cannot be used because 'paramiko' is not installed. <pip install paramiko>")
+
 
 def get_client(ip: str, username: str, pem: Optional[Union[str, Path]] = None):
+
     client = SSHClient()
     client.load_system_host_keys()
     client.set_missing_host_key_policy(AutoAddPolicy())
